@@ -228,7 +228,7 @@ iconv_cache_init (void)
 }
 
 
-/**
+/*
  * iconv_cache_bucket_new:
  * @key: cache key
  * @cd: iconv descriptor
@@ -263,7 +263,7 @@ iconv_cache_bucket_new (gchar *key, GIConv cd)
 }
 
 
-/**
+/*
  * iconv_cache_bucket_expire:
  * @node: cache bucket's node
  * @bucket: cache bucket
@@ -308,7 +308,7 @@ iconv_cache_bucket_expire (GList *node, struct _iconv_cache_bucket *bucket)
 }
 
 
-/**
+/*
  * iconv_cache_expire_unused:
  *
  * Expires as many unused cache buckets as it needs to in order to get
@@ -573,13 +573,13 @@ g_convert_with_iconv (const gchar *str,
   gchar *dest;
   gchar *outp;
   const gchar *p;
-  const gchar *shift_p = NULL;
   gsize inbytes_remaining;
   gsize outbytes_remaining;
   gsize err;
   gsize outbuf_size;
   gboolean have_error = FALSE;
   gboolean done = FALSE;
+  gboolean reset = FALSE;
   
   g_return_val_if_fail (converter != (GIConv) -1, NULL);
      
@@ -595,7 +595,10 @@ g_convert_with_iconv (const gchar *str,
 
   while (!done && !have_error)
     {
-      err = g_iconv (converter, (char **)&p, &inbytes_remaining, &outp, &outbytes_remaining);
+      if (reset)
+        err = g_iconv (converter, NULL, &inbytes_remaining, &outp, &outbytes_remaining);
+      else
+        err = g_iconv (converter, (char **)&p, &inbytes_remaining, &outp, &outbytes_remaining);
 
       if (err == (gsize) -1)
 	{
@@ -633,11 +636,10 @@ g_convert_with_iconv (const gchar *str,
 	}
       else 
 	{
-	  if (!shift_p)
+	  if (!reset)
 	    {
 	      /* call g_iconv with NULL inbuf to cleanup shift state */
-	      shift_p = p;
-	      p = NULL;
+	      reset = TRUE;
 	      inbytes_remaining = 0;
 	    }
 	  else
@@ -645,9 +647,6 @@ g_convert_with_iconv (const gchar *str,
 	}
     }
 
-  if (shift_p)
-    p = shift_p;
-
   *outp = '\0';
   
   if (bytes_read)
