@@ -936,7 +936,7 @@ fdwalk (int (*cb)(void *data, int fd), void *data)
   
 #ifdef HAVE_SYS_RESOURCE_H
       
-  if (getrlimit(RLIMIT_NOFILE, &rl) == 0)
+  if (getrlimit(RLIMIT_NOFILE, &rl) == 0 && rl.rlim_max != RLIM_INFINITY)
       open_max = rl.rlim_max;
   else
 #endif
