@@ -610,13 +610,12 @@ g_ascii_formatd (gchar       *buffer,
 	{
 	  *p = '.';
 	  p++;
-	  if (decimal_point_len > 1) {
-	    rest_len = strlen (p + (decimal_point_len-1));
-	    memmove (p, p + (decimal_point_len-1),
-		     rest_len);
-	    p[rest_len] = 0;
-	    
-	  }
+	  if (decimal_point_len > 1) 
+            {
+	      rest_len = strlen (p + (decimal_point_len-1));
+	      memmove (p, p + (decimal_point_len-1), rest_len);
+	      p[rest_len] = 0;
+	    }
 	}
     }
   
@@ -651,9 +650,12 @@ g_parse_long_long (const gchar *nptr,
   
   g_return_val_if_fail (nptr != NULL, 0);
   
+  *negative = FALSE;
   if (base == 1 || base > 36)
     {
       errno = EINVAL;
+      if (endptr)
+	*endptr = nptr;
       return 0;
     }
   
@@ -667,7 +669,6 @@ g_parse_long_long (const gchar *nptr,
     goto noconv;
   
   /* Check for a sign.  */
-  *negative = FALSE;
   if (*s == '-')
     {
       *negative = TRUE;
@@ -2288,13 +2289,10 @@ g_strsplit (const gchar *string,
       while (--max_tokens && s)
 	{
 	  gsize len;     
-	  gchar *new_string;
 
 	  len = s - remainder;
-	  new_string = g_new (gchar, len + 1);
-	  strncpy (new_string, remainder, len);
-	  new_string[len] = 0;
-	  string_list = g_slist_prepend (string_list, new_string);
+	  string_list = g_slist_prepend (string_list,
+					 g_strndup (remainder, len));
 	  n++;
 	  remainder = s + delimiter_len;
 	  s = strstr (remainder, delimiter);
@@ -2431,8 +2429,8 @@ g_strfreev (gchar **str_array)
     {
       int i;
 
-      for(i = 0; str_array[i] != NULL; i++)
-	g_free(str_array[i]);
+      for (i = 0; str_array[i] != NULL; i++)
+	g_free (str_array[i]);
 
       g_free (str_array);
     }
