@@ -47,6 +47,7 @@ struct _GString
  */
 GStringChunk* g_string_chunk_new	   (gsize size);  
 void	      g_string_chunk_free	   (GStringChunk *chunk);
+void	      g_string_chunk_clear	   (GStringChunk *chunk);
 gchar*	      g_string_chunk_insert	   (GStringChunk *chunk,
 					    const gchar	 *string);
 gchar*	      g_string_chunk_insert_len	   (GStringChunk *chunk,
@@ -104,14 +105,27 @@ GString*     g_string_insert_c          (GString	 *string,
 GString*     g_string_insert_unichar    (GString	 *string,
 					 gssize		  pos,    
 					 gunichar	  wc);
+GString*     g_string_overwrite         (GString	 *string,
+					 gsize		  pos,    
+					 const gchar	 *val);
+GString*     g_string_overwrite_len     (GString	 *string,
+					 gsize		  pos,    
+					 const gchar	 *val,
+					 gssize           len);
 GString*     g_string_erase	        (GString	 *string,
 					 gssize		  pos,
 					 gssize		  len);
 GString*     g_string_ascii_down        (GString	 *string);
 GString*     g_string_ascii_up          (GString	 *string);
+void         g_string_vprintf           (GString	 *string,
+					 const gchar	 *format,
+					 va_list          args);
 void         g_string_printf            (GString	 *string,
 					 const gchar	 *format,
 					 ...) G_GNUC_PRINTF (2, 3);
+void         g_string_append_vprintf    (GString	 *string,
+					 const gchar	 *format,
+					 va_list          args);
 void         g_string_append_printf     (GString	 *string,
 					 const gchar	 *format,
 					 ...) G_GNUC_PRINTF (2, 3);
@@ -122,7 +136,7 @@ static inline GString*
 g_string_append_c_inline (GString *gstring,
                           gchar    c)
 {
-  if (gstring->len < gstring->allocated_len && 0)
+  if (gstring->len + 1 < gstring->allocated_len)
     {
       gstring->str[gstring->len++] = c;
       gstring->str[gstring->len] = 0;
