@@ -47,8 +47,18 @@
       ? CC_PART2 (((Char) - 0xe0000) >> 8, (Char) & 0xff) \
       : 0))
 
+/**
+ * g_unichar_combining_class:
+ * @uc: a Unicode character
+ * 
+ * Determines the canonical combining class of a Unicode character.
+ * 
+ * Return value: the combining class of the character
+ *
+ * Since: 2.14
+ **/
 gint
-_g_unichar_combining_class (gunichar uc)
+g_unichar_combining_class (gunichar uc)
 {
   return COMBINING_CLASS (uc);
 }
@@ -442,7 +452,7 @@ _g_utf8_normalize_wc (const gchar    *str,
 	  int cc = COMBINING_CLASS (wc_buffer[i]);
 
 	  if (i > 0 &&
-	      (last_cc == 0 || last_cc != cc) &&
+	      (last_cc == 0 || last_cc < cc) &&
 	      combine (wc_buffer[last_start], wc_buffer[i],
 		       &wc_buffer[last_start]))
 	    {
