@@ -427,8 +427,11 @@ g_module_open (const gchar    *file_name,
 	  gchar *real_name = parse_libtool_archive (name);
 
 	  /* real_name might be NULL, but then module error is already set */
-	  g_free (name);
-	  name = real_name;
+          if (real_name)
+            {
+	      g_free (name);
+	      name = real_name;
+            }
 	}
       if (name)
 	handle = _g_module_open (name, (flags & G_MODULE_BIND_LAZY) != 0,
@@ -488,7 +491,10 @@ g_module_open (const gchar    *file_name,
 	{
 	  gchar *error;
 
-	  error = g_strconcat ("GModule initialization check failed: ", check_failed, NULL);
+	  error = g_strconcat ("GModule (", 
+                               file_name ? file_name : "NULL", 
+                               ") initialization check failed: ", 
+                               check_failed, NULL);
 	  g_module_close (module);
 	  module = NULL;
 	  g_module_set_error (error);
