@@ -96,6 +96,9 @@ G_BEGIN_DECLS
 #define	G_TYPE_PARAM_OVERRIDE		   (g_param_spec_types[20])
 #define G_IS_PARAM_SPEC_OVERRIDE(pspec)    (G_TYPE_CHECK_INSTANCE_TYPE ((pspec), G_TYPE_PARAM_OVERRIDE))
 #define G_PARAM_SPEC_OVERRIDE(pspec)       (G_TYPE_CHECK_INSTANCE_CAST ((pspec), G_TYPE_PARAM_OVERRIDE, GParamSpecOverride))
+#define	G_TYPE_PARAM_GTYPE		   (g_param_spec_types[21])
+#define G_IS_PARAM_SPEC_GTYPE(pspec)       (G_TYPE_CHECK_INSTANCE_TYPE ((pspec), G_TYPE_PARAM_GTYPE))
+#define G_PARAM_SPEC_GTYPE(pspec)          (G_TYPE_CHECK_INSTANCE_CAST ((pspec), G_TYPE_PARAM_GTYPE, GParamSpecGType))
 
 
 /* --- typedefs & structures --- */
@@ -120,6 +123,7 @@ typedef struct _GParamSpecPointer    GParamSpecPointer;
 typedef struct _GParamSpecValueArray GParamSpecValueArray;
 typedef struct _GParamSpecObject     GParamSpecObject;
 typedef struct _GParamSpecOverride   GParamSpecOverride;
+typedef struct _GParamSpecGType      GParamSpecGType;
 
 struct _GParamSpecChar
 {
@@ -268,6 +272,11 @@ struct _GParamSpecOverride
   GParamSpec    parent_instance;
   GParamSpec   *overridden;
 };
+struct _GParamSpecGType
+{
+  GParamSpec    parent_instance;
+  GType         is_a_type;
+};
 
 /* --- GParamSpec prototypes --- */
 GParamSpec*	g_param_spec_char	 (const gchar	 *name,
@@ -391,9 +400,13 @@ GParamSpec*	g_param_spec_object	 (const gchar	 *name,
 					  const gchar	 *blurb,
 					  GType		  object_type,
 					  GParamFlags	  flags);
-
 GParamSpec*     g_param_spec_override    (const gchar    *name,
 					  GParamSpec     *overridden);
+GParamSpec*	g_param_spec_gtype	 (const gchar	 *name,
+					  const gchar	 *nick,
+					  const gchar	 *blurb,
+					  GType           is_a_type,
+					  GParamFlags	  flags);
 
 /* --- internal --- */
 /* We prefix variable declarations so they can
