@@ -546,12 +546,18 @@ g_thread_join_win32_impl (gpointer thread)
 }
 
 static guint64
-g_gettime_win32_impl (void)
+g_thread_gettime_impl (void)
 {
   guint64 v;
 
+  /* Returns 100s of nanoseconds since start of 1601 */
   GetSystemTimeAsFileTime ((FILETIME *)&v);
 
+  /* Offset to Unix epoch */
+  v -= G_GINT64_CONSTANT (116444736000000000);
+  /* Convert to nanoseconds */
+  v *= 100;
+
   return v;
 }
 
@@ -577,8 +583,7 @@ static GThreadFunctions g_thread_functions_for_glib_use_default =
   g_thread_exit_win32_impl,
   g_thread_set_priority_win32_impl,
   g_thread_self_win32_impl,
-  NULL,                             /* no equal function necessary */
-  g_gettime_win32_impl
+  NULL                             /* no equal function necessary */
 };
 
 #define HAVE_G_THREAD_IMPL_INIT
@@ -602,10 +607,10 @@ g_thread_impl_init ()
   InitializeCriticalSection (&g_thread_global_spinlock);
 
   /* Here we are looking for TryEnterCriticalSection in KERNEL32.DLL,
-   * if it is found, we can use the faster critical sections instead
-   * of mutexes. Note however that
-   * http://www2.awl.com/cseng/titles/0-201-63465-1/csmutx.htm indicates,
-   * that critical sections might not be ideal after all on SMP machines */
+   * if it is found, we can use the in general faster critical
+   * sections instead of mutexes. See
+   * http://world.std.com/~jmhart/csmutx.htm for some discussion.
+   */
   kernel32 = GetModuleHandle ("KERNEL32.DLL");
   if (kernel32)
     {
